# NeuralNets

This code implements various useful utilities for training neural networks (particularly for segmentation).

## Installation
Installation is straightforward through pip:
<pre><code>pip install neuralnets</code></pre>
